@@ -43,8 +43,7 @@ class InsightsMixin:
             List of dictionaries of response from the call
         """
         assert self.user_id, "Login required"
-        supported_post_types = ("ALL", "CAROUSEL_V2",
-                                "IMAGE", "SHOPPING", "VIDEO")
+        supported_post_types = ("ALL", "CAROUSEL_V2", "IMAGE", "SHOPPING", "VIDEO")
         supported_time_frames = (
             "ONE_WEEK",
             "ONE_MONTH",
@@ -82,7 +81,8 @@ class InsightsMixin:
                 query_params["cursor"] = cursor
 
             result = self.private_request(
-                "ads/graphql/", self.with_query_params(data, query_params),
+                "ads/graphql/",
+                self.with_query_params(data, query_params),
             )
             if not json_value(
                 result,
@@ -91,8 +91,7 @@ class InsightsMixin:
                 "business_manager",
                 default=None,
             ):
-                raise UserError(
-                    "Account is not business account", **self.last_json)
+                raise UserError("Account is not business account", **self.last_json)
 
             stats = result["data"]["shadow_instagram_user"]["business_manager"][
                 "top_posts_unit"
@@ -139,13 +138,12 @@ class InsightsMixin:
         }
 
         result = self.private_request(
-            "ads/graphql/", self.with_query_params(data, query_params),
+            "ads/graphql/",
+            self.with_query_params(data, query_params),
         )
-        res = json_value(
-            result, "data", "shadow_instagram_user", "business_manager")
+        res = json_value(result, "data", "shadow_instagram_user", "business_manager")
         if not res:
-            raise UserError("Account is not business account",
-                            **self.last_json)
+            raise UserError("Account is not business account", **self.last_json)
         return res
 
     def insights_media(self, media_pk: int) -> Dict:
@@ -177,8 +175,9 @@ class InsightsMixin:
         }
         try:
             result = self.private_request(
-                "ads/graphql/", self.with_query_params(data, query_params),
+                "ads/graphql/",
+                self.with_query_params(data, query_params),
             )
-            return result['data']['instagram_post_by_igid']
+            return result["data"]["instagram_post_by_igid"]
         except ClientError as e:
             raise MediaError(e.message, media_pk=media_pk, **self.last_json)
